@@ -1,5 +1,4 @@
 import os
-from abc import ABC
 from dataclasses import dataclass
 from typing import TypeVar
 
@@ -9,7 +8,7 @@ MediaT = TypeVar("MediaT", bound="Media")
 
 
 @dataclass
-class Media(ABC):
+class Media:
     """媒体
 
     path: 本地路径或URL
@@ -22,9 +21,6 @@ class Media(ABC):
     thumb_url: str = None
     width: int = 0
     height: int = 0
-    duration: int = 0
-    """视频时长，单位秒"""
-    subtitles: Subtitles = None
 
     def __str__(self):
         return str(self.path)
@@ -58,6 +54,7 @@ class Video(Media):
     ext: str = "mp4"
     thumb_url: str = None
     duration: int = 0
+    """视频时长，单位秒"""
     width: int = 0
     height: int = 0
     subtitles: Subtitles = None
