@@ -1,6 +1,5 @@
 from dataclasses import dataclass
 from pathlib import Path
-from typing import List
 from xml.etree import ElementTree
 
 
@@ -13,7 +12,7 @@ class Subtitle:
 
 @dataclass
 class Subtitles:
-    def __init__(self, subtitles: List[Subtitle] | None = None):
+    def __init__(self, subtitles: list[Subtitle] | None = None):
         self.subtitles = subtitles
 
     @classmethod
@@ -41,9 +40,7 @@ class Subtitles:
         return cls(subtitles=subtitles)
 
     def to_str(self) -> str:
-        return "\n".join(
-            [f"{i.begin}-{i.end}: {i.text}" for i in self.subtitles]
-        ).strip()
+        return "\n".join([f"{i.begin}-{i.end}: {i.text}" for i in self.subtitles]).strip()
 
     def __str__(self) -> str:
         return self.to_str()
